%ifarch x86_64
%global bit x86_64
%else
%ifarch armv7hl
%global bit armv7hl
%else
%ifarch ppc64
%global bit ppc64
%else
%ifarch ppc64le
%global bit ppc64le
%else
%ifarch aarch64
%global bit aarch64
%else
%global bit x86
%endif
%endif
%endif
%endif
%endif

%define rname   TuxGuitar

%define fluidsynth 1

Name:           tuxguitar
Version:        1.5.3
Release:        %mkrel 3
Summary:        Multitrack guitar tablature editor and player
License:        LGPLv2+
Group:          Sound/Midi
URL:            http://www.tuxguitar.com.ar/
#Source0:	http://downloads.sourceforge.net/%{name}/%{name}-src-%{version}.tar.gz
# Source file cleaned of potentially proprietary SF2, DLL, EXE files:
#   wget -N http://downloads.sourceforge.net/tuxguitar/tuxguitar-1.5.3-src.tar.gz
#   tar zxf tuxguitar-1.5.3-src.tar.gz
#   find tuxguitar-1.5.3-src -name "*.exe" -exec rm {} \;
#   find tuxguitar-1.5.3-src -name "*.dll" -exec rm {} \;
#   find tuxguitar-1.5.3-src -name "*.sf2" -exec rm {} \;
#   tar zcf tuxguitar-1.5.3-src-clean.tar.gz tuxguitar-1.5.3-src
Source0:        %{name}-%{version}-src-clean.tar.gz

# Fedora specific start script
Patch0:         tuxguitar-startscript.patch
# Fedora specific default soundfont path
Patch1:         tuxguitar-default-soundfont.patch
# Build scripts for Fedora's additional arches
Patch2:         tuxguitar-additional-arch.patch
# Fix linking
Patch3:         tuxguitar-pthread.patch

Patch4:         tuxguitar-1.5.3-fix-start.patch

# eclipse-swt upstream stopped supporting non-64bit arches at version 4.11
ExcludeArch:    s390 %{arm} %{ix86}

BuildRequires:  appstream-util
BuildRequires:  desktop-file-utils
BuildRequires:  pkgconfig(alsa)
%if %{fluidsynth}
BuildRequires:  pkgconfig(fluidsynth)
%endif
BuildRequires:  pkgconfig(jack)

BuildRequires:  eclipse-swt
BuildRequires:  maven-local
BuildRequires:  maven-antrun-plugin

Requires:       eclipse-swt
Requires:       hicolor-icon-theme
Requires:       soundfont2-default

Provides:       %{rname} = %{version}-%{release}

%description
TuxGuitar is a multitrack guitar tablature editor and player written
in Java-SWT.

With TuxGuitar, you will be able to compose music using the
following features:

    * Tablature editor
    * Score Viewer
    * Multitrack display
    * Autoscroll while playing
    * Note duration management
    * Various effects (bend, slide, vibrato, hammer-on/pull-off)
    * Support for triplets (5,6,7,9,10,11,12)
    * Repeat open and close
    * Time signature management
    * Tempo management
    * Imports and exports gp3, gp4 and gp5 files

%prep
%setup -q -n %{name}-%{version}-src
%autopatch -p1

# Remove prebuilt jar, class files
find . -name "*.jar" -exec rm {} \;
find . -name "*.class" -exec rm {} \;

# Remove NON FREE deps
%pom_remove_dep -r com.itextpdf:itextpdf
%pom_remove_dep -r com.itextpdf.tool:xmlworker
%pom_remove_dep -r com.itextpdf:itextpdf build-scripts/%{name}-linux-%{bit}
%pom_remove_dep -r com.itextpdf.tool:xmlworker build-scripts/%{name}-linux-%{bit}
%pom_disable_module ../../TuxGuitar-pdf build-scripts/%{name}-linux-%{bit}
%pom_remove_dep -r :tuxguitar-pdf
%pom_disable_module ../../TuxGuitar-pdf-ui build-scripts/%{name}-linux-%{bit}
%pom_remove_dep -r :tuxguitar-pdf-ui

# Fails to collect eclipse swt artifact
%pom_remove_plugin :maven-dependency-plugin build-scripts/%{name}-linux-%{bit}
%pom_remove_plugin :maven-dependency-plugin build-scripts/native-modules/%{name}-alsa-linux-%{bit}
%pom_remove_plugin :maven-dependency-plugin build-scripts/native-modules/%{name}-fluidsynth-linux-%{bit}
%pom_remove_plugin :maven-dependency-plugin build-scripts/native-modules/%{name}-jack-linux-%{bit}
%pom_remove_plugin :maven-dependency-plugin build-scripts/native-modules/%{name}-oss-linux-%{bit}

%pom_xpath_set -r pom:org.eclipse.swt.artifactId org.eclipse.swt
%pom_xpath_set -r pom:org.eclipse.swt.artifactId org.eclipse.swt build-scripts/%{name}-linux-%{bit}
%pom_remove_dep :org.eclipse.swt.gtk.linux.x86
%pom_remove_dep :org.eclipse.swt.gtk.linux.x86_64
%pom_remove_dep :org.eclipse.swt.gtk.linux.ppc
%pom_remove_dep :org.eclipse.swt.win32.win32.x86
%pom_remove_dep :org.eclipse.swt.cocoa.macosx
%pom_remove_dep :org.eclipse.swt.cocoa.macosx.x86_64
%pom_remove_dep :org.eclipse.swt.carbon.macosx

%if %{fluidsynth}
%pom_xpath_inject pom:modules "<module>../../TuxGuitar-alsa</module>
 <module>../../TuxGuitar-fluidsynth</module>
 <module>../../TuxGuitar-jack-ui</module>
 <module>../../TuxGuitar-jack</module>
 <module>../../TuxGuitar-oss</module>
 <module>../../TuxGuitar-tray</module>
 <module>../../TuxGuitar-viewer</module>"  build-scripts/%{name}-linux-%{bit}
%else
%pom_xpath_inject pom:modules "<module>../../TuxGuitar-alsa</module>
 <module>../../TuxGuitar-jack-ui</module>
 <module>../../TuxGuitar-jack</module>
 <module>../../TuxGuitar-oss</module>
 <module>../../TuxGuitar-tray</module>
 <module>../../TuxGuitar-viewer</module>"  build-scripts/%{name}-linux-%{bit}
%endif

# Fix parent pom for jni modules
%pom_xpath_set pom:parent/pom:artifactId tuxguitar-alsa-linux-%{bit} TuxGuitar-alsa
%pom_xpath_inject pom:parent "<relativePath>../build-scripts/native-modules/tuxguitar-alsa-linux-%{bit}</relativePath>" TuxGuitar-alsa
%pom_xpath_set pom:parent/pom:artifactId tuxguitar-fluidsynth-linux-%{bit} TuxGuitar-fluidsynth
%pom_xpath_inject pom:parent "<relativePath>../build-scripts/native-modules/tuxguitar-fluidsynth-linux-%{bit}</relativePath>" TuxGuitar-fluidsynth
%pom_xpath_set pom:parent/pom:artifactId tuxguitar-jack-linux-%{bit} TuxGuitar-jack
%pom_xpath_inject pom:parent "<relativePath>../build-scripts/native-modules/tuxguitar-jack-linux-%{bit}</relativePath>" TuxGuitar-jack-ui
%pom_xpath_set pom:parent/pom:artifactId tuxguitar-jack-linux-%{bit} TuxGuitar-jack-ui
%pom_xpath_inject pom:parent "<relativePath>../build-scripts/native-modules/tuxguitar-jack-linux-%{bit}</relativePath>" TuxGuitar-jack
%pom_xpath_set pom:parent/pom:artifactId tuxguitar-oss-linux-%{bit} TuxGuitar-oss
%pom_xpath_inject pom:parent "<relativePath>../build-scripts/native-modules/tuxguitar-oss-linux-%{bit}</relativePath>" TuxGuitar-oss

# fix tuxguitar-*.jni.path property
sed -i "s|\${parent.relativePath}|$PWD|" \
    build-scripts/native-modules/tuxguitar-alsa-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-fluidsynth-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-jack-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-oss-linux-%{bit}/pom.xml
#fix libdir
sed -i 's|-L/usr/lib|-L%{_libdir}|' \
    build-scripts/native-modules/tuxguitar-alsa-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-fluidsynth-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-jack-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-oss-linux-%{bit}/pom.xml
# Disable gcj support and add default compiler flags
sed -i -e "s|\$(shell gcj -print-file-name=include/)|%{_jvmdir}/java/include -I%{_jvmdir}/java/include/linux $RPM_OPT_FLAGS|" \
    -e "s|\(</tuxguitar-.*.jni.ldflags>\)| $RPM_LD_FLAGS\1|" \
    -e "s|\(</tuxguitar-.*.jni.cflags>\)| -I/usr/lib/jvm/java/include/ -I/usr/lib/jvm/java/include/linux/ $RPM_OPT_FLAGS\1|" \
    build-scripts/native-modules/tuxguitar-alsa-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-fluidsynth-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-jack-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-oss-linux-%{bit}/pom.xml
#for i in TuxGuitar-*; do echo "   " \[ -r \"\$t\" \] \&\& CLASSPATH=\${CLASSPATH}:\$t;echo "   " t="\${PACKAGE_HOME}/$i.jar"; done |sed 's|TuxGuitar|${PACKAGE}|'
# Fix version tags
sed -i -e "s|\(<version>\).*\(</version>\)|\1%{version}\2|"\
    build-scripts/native-modules/tuxguitar-alsa-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-fluidsynth-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-jack-linux-%{bit}/pom.xml \
    build-scripts/native-modules/tuxguitar-oss-linux-%{bit}/pom.xml \
    build-scripts/tuxguitar-linux-%{bit}/pom.xml

%build
# -j for excluding the javadoc, since this is an application
%mvn_build -j -- -e -f build-scripts/%{name}-linux-%{bit}/pom.xml -Dproject.build.sourceEncoding=UTF-8

%install
%mvn_install
# install jnis we built
mkdir -p %{buildroot}%{_libdir}/%{name}
cp -a TuxGuitar-*/jni/*.so %{buildroot}%{_libdir}/%{name}/

# Launch script
mkdir -p %{buildroot}%{_bindir}
cp -a misc/tuxguitar.sh %{buildroot}%{_bindir}/%{name}

# Fix permissions
chmod 755 %{buildroot}%{_bindir}/%{name}
chmod 755 %{buildroot}%{_libdir}/%{name}/*.so

# mime types
mkdir -p %{buildroot}/%{_datadir}/mime/packages/
cp -a misc/tuxguitar.xml %{buildroot}/%{_datadir}/mime/packages/

# data files
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -a TuxGuitar/share/* %{buildroot}%{_datadir}/%{name}
# This file doesn't launch at this point. Might work when we can get the plugins working
cp -a misc/tuxguitar.tg %{buildroot}%{_datadir}/%{name}
cp -a build-scripts/%{name}-linux-%{bit}/target/%{name}-%{version}-linux-%{bit}/dist/* %{buildroot}%{_datadir}/%{name}

# jars connected to the jnis
cp -a TuxGuitar-alsa/target/%{name}-alsa-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}-alsa.jar
%if %{fluidsynth}
cp -a TuxGuitar-fluidsynth/target/%{name}-fluidsynth-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}-fluidsynth.jar
%endif
cp -a TuxGuitar-jack/target/%{name}-jack-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}-jack.jar
cp -a TuxGuitar-oss/target/%{name}-oss-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}-oss.jar

# These didn't work
#jpackage_script org.herac.tuxguitar.app.TGMain "" "" tuxguitar tuxguitar true
#jpackage_script org.herac.tuxguitar.app.TGMain "-Xmx512m" "" swt:tuxguitar tuxguitar true

# Lavender ersplus blue_serious
STYLE=Oxygen

for dim in 16 24 32 48 64 96; do
    mkdir -p %{buildroot}%{_iconsdir}/hicolor/${dim}x${dim}/apps/
    mkdir -p %{buildroot}%{_iconsdir}/hicolor/${dim}x${dim}/mimetypes/
    cp -a TuxGuitar/share/skins/${STYLE}/icon-${dim}x${dim}.png %{buildroot}%{_iconsdir}/hicolor/${dim}x${dim}/apps/%{name}.png
    cp -a TuxGuitar/share/skins/${STYLE}/icon-${dim}x${dim}.png %{buildroot}%{_iconsdir}/hicolor/${dim}x${dim}/mimetypes/audio-x-%{name}.png
    cp -a TuxGuitar/share/skins/${STYLE}/icon-${dim}x${dim}.png %{buildroot}%{_iconsdir}/hicolor/${dim}x${dim}/mimetypes/audio-x-gtp.png
    cp -a TuxGuitar/share/skins/${STYLE}/icon-${dim}x${dim}.png %{buildroot}%{_iconsdir}/hicolor/${dim}x${dim}/mimetypes/audio-x-ptb.png
done

# man page
mkdir -p %{buildroot}%{_mandir}/man1
cp -a misc/%{name}.1 %{buildroot}%{_mandir}/man1/    
    
# Register as an application to be visible in the software center
#
# NOTE: It would be *awesome* if this file was maintained by the upstream
# project, translated and installed into the right place during `make install`.
#
# See http://www.freedesktop.org/software/appstream/docs/ for more details.
#
mkdir -p %{buildroot}%{_datadir}/metainfo
cat > %{buildroot}%{_datadir}/metainfo/%{name}.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright 2014 Richard Hughes <richard@hughsie.com> -->
<!--
BugReportURL: https://sourceforge.net/p/tuxguitar/support-requests/8/
SentUpstream: 2014-09-22
-->
<application>
  <id type="desktop">tuxguitar.desktop</id>
  <metadata_license>CC0-1.0</metadata_license>
  <summary>A multitrack tablature editor and player</summary>
  <description>
  <p>
    Tuxguitar is a multitrack tablature editor and player.
    It provides the following features:
  </p>
  <ul>
    <li>Tablature editor</li>
    <li>Score Viewer</li>
    <li>Multitrack display</li>
    <li>Autoscroll while playing</li>
    <li>Note duration management</li>
    <li>Various effects (bend, slide, vibrato, hammer-on/pull-off)</li>
    <li>Support for triplets (5,6,7,9,10,11,12)</li>
    <li>Repeat open and close</li>
    <li>Time signature management</li>
    <li>Tempo management</li>
    <li>Imports and exports gp3,gp4 and gp5 files</li>
  </ul>
  </description>
  <url type="homepage">http://www.tuxguitar.com.ar/</url>
  <screenshots>
    <screenshot type="default">http://www.tuxguitar.com.ar/rd.php/gallery/show_picture.do?galid=1&amp;picid=47</screenshot>
    <screenshot>http://www.tuxguitar.com.ar/rd.php/gallery/show_picture.do?galid=1&amp;picid=46</screenshot>
  </screenshots>
</application>
EOF

%check
desktop-file-install --dir=%{buildroot}%{_datadir}/applications misc/tuxguitar.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/%{name}.appdata.xml

%files -f .mfiles
%doc AUTHORS CHANGES README
%license LICENSE
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_iconsdir}/hicolor/*/mimetypes/*.png
%{_mandir}/man1/%{name}.1*

%{_javadir}/%{name}/tuxguitar-alsa.jar
%if %{fluidsynth}
%{_javadir}/%{name}/tuxguitar-fluidsynth.jar
%endif
%{_javadir}/%{name}/tuxguitar-jack.jar
%{_javadir}/%{name}/tuxguitar-oss.jar


%changelog
* Thu Dec 17 2020 neoclust <neoclust> 1.5.3-3.mga8
+ Revision: 1659911
- Always use java to start tuxguitar (mga#27855)

* Thu Feb 20 2020 umeabot <umeabot> 1.5.3-2.mga8
+ Revision: 1547362
- Mageia 8 Mass Rebuild

* Sat Feb 08 2020 daviddavid <daviddavid> 1.5.3-1.mga8
+ Revision: 1488019
- new version: 1.5.3
- re-enable fluidsynth
- don't build on 32bit arches as eclipse-swt is no longer available
  starting at version 4.11

* Mon Jan 14 2019 luigiwalser <luigiwalser> 1.5.2-3.mga7
+ Revision: 1356841
- disable fluidsynth
- rebuild for fluidsynth

* Mon Oct 22 2018 wally <wally> 1.5.2-2.mga7
+ Revision: 1323589
- add patch to fix linking

* Sun Sep 09 2018 daviddavid <daviddavid> 1.5.2-1.mga7
+ Revision: 1257978
- new version: 1.5.2

* Wed May 02 2018 daviddavid <daviddavid> 1.5.1-1.mga7
+ Revision: 1224451
- new version: 1.5.1

* Fri Mar 02 2018 daviddavid <daviddavid> 1.5-1.mga7
+ Revision: 1206031
- new version: 1.5

* Sun Dec 25 2016 daviddavid <daviddavid> 1.4-1.mga6
+ Revision: 1077284
- new version: 1.4 (based on fedora and fixes mga#17725)

* Mon Feb 08 2016 umeabot <umeabot> 1.2-16.mga6
+ Revision: 950503
- Mageia 6 Mass Rebuild

* Wed Nov 05 2014 tv <tv> 1.2-15.mga5
+ Revision: 795722
- Drop no longer needed BuildRequires on java-rpmbuild

* Wed Oct 15 2014 umeabot <umeabot> 1.2-14.mga5
+ Revision: 749608
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2-13.mga5
+ Revision: 689981
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.2-12.mga4
+ Revision: 530942
- Mageia 4 Mass Rebuild

* Tue Jul 30 2013 joequant <joequant> 1.2-11.mga4
+ Revision: 461052
- remove ant-nodeps and ant-trax from buildrequires

* Mon Jan 14 2013 umeabot <umeabot> 1.2-10.mga3
+ Revision: 384851
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 21 2012 zezinho <zezinho> 1.2-9.mga3
+ Revision: 320031
- fix group
- xulrunner is no more here

* Mon Jun 11 2012 zezinho <zezinho> 1.2-8.mga3
+ Revision: 259865
- less optimised build as it crashes on some i586 #1760

* Sun Jun 12 2011 wally <wally> 1.2-7.mga2
+ Revision: 105382
- disable ALSA plugin for now as it crashes the program at startup (mga#1760)

* Sat Apr 30 2011 wally <wally> 1.2-6.mga1
+ Revision: 93641
- drop old obsoletes/provides
- drop buildroot definition
- imported package tuxguitar


* Fri Jan 07 2011 Jani Välimaa <wally@mandriva.org> 1.2-6mdv2011.0
+ Revision: 629446
- drop gcj support

* Fri Oct 15 2010 Jani Välimaa <wally@mandriva.org> 1.2-5mdv2011.0
+ Revision: 585777
- fix CVE-2010-3385 insecure library loading vulnerability (RHBZ#638396)

* Wed Mar 24 2010 Jani Välimaa <wally@mandriva.org> 1.2-4mdv2010.1
+ Revision: 527218
- define correct MOZILLA_FIVE_HOME path on run time, not on build time

* Sat Feb 27 2010 Jani Välimaa <wally@mandriva.org> 1.2-3mdv2010.1
+ Revision: 512475
- obsolete old javadoc package

* Sat Feb 27 2010 Jani Välimaa <wally@mandriva.org> 1.2-2mdv2010.1
+ Revision: 512385
- bump java requires

* Thu Feb 25 2010 Jani Välimaa <wally@mandriva.org> 1.2-1mdv2010.1
+ Revision: 510936
- rewrite .spec (based on .spec from Fedora)
- use Fedora specific build script from upstream svn
- disable certain plugins by default (Patch0, from upstream svn)

  + Funda Wang <fwang@mandriva.org>
    - new version 1.2

* Fri May 01 2009 Frederik Himpe <fhimpe@mandriva.org> 0:1.1-1mdv2010.0
+ Revision: 370005
- update to new version 1.1

* Fri Apr 10 2009 Michael Scherer <misc@mandriva.org> 0:1.0-0.0.5mdv2009.1
+ Revision: 365817
- update the Group tag, as signaled on irc

* Wed Oct 01 2008 David Walluck <walluck@mandriva.org> 0:1.0-0.0.4mdv2009.0
+ Revision: 290475
- fix startup by appending /usr/lib to java.library.path

* Sun Aug 17 2008 David Walluck <walluck@mandriva.org> 0:1.0-0.0.3mdv2009.0
+ Revision: 273022
- Provides/Obsoletes: %%{name}-alsa
- fix build with eclipse-swt

* Tue Jul 29 2008 David Walluck <walluck@mandriva.org> 0:1.0-0.0.1mdv2009.0
+ Revision: 252909
- BuildRequires: fluidsynth-devel
- 1.0

* Thu Feb 07 2008 David Walluck <walluck@mandriva.org> 0:0.9.1-12mdv2008.1
+ Revision: 163816
- fix menu category

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:0.9.1-11mdv2008.1
+ Revision: 121040
- buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Mon Nov 26 2007 David Walluck <walluck@mandriva.org> 0:0.9.1-10mdv2008.1
+ Revision: 113245
- rebuild to fix swt-gtk dependency

* Tue Sep 18 2007 David Walluck <walluck@mandriva.org> 0:0.9.1-9mdv2008.0
+ Revision: 89370
- build with icedtea

* Mon Sep 17 2007 David Walluck <walluck@mandriva.org> 0:0.9.1-8mdv2008.0
+ Revision: 88900
- fix itext in launch script

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:0.9.1-7mdv2008.0
+ Revision: 87218
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Sat Sep 01 2007 David Walluck <walluck@mandriva.org> 0:0.9.1-6mdv2008.0
+ Revision: 77734
- update for eclipse 3.3
- remove javax.print patch which is no longer needed
- rename no-java-1.5 patch to something midi-related

* Tue Apr 17 2007 David Walluck <walluck@mandriva.org> 0:0.9.1-5mdv2008.0
+ Revision: 14117
- use itext instead of itext2


* Sat Apr 07 2007 David Walluck <walluck@mandriva.org> 0.9.1-4mdv2007.1
+ Revision: 151231
- run aoss from menu, not script

* Fri Apr 06 2007 David Walluck <walluck@mandriva.org> 0:0.9.1-3mdv2007.1
+ Revision: 150786
- use aoss

* Sat Mar 17 2007 David Walluck <walluck@mandriva.org> 0:0.9.1-2mdv2007.1
+ Revision: 145556
- really fix menu category
- add menu category

* Sun Mar 04 2007 David Walluck <walluck@mandriva.org> 0:0.9.1-1mdv2007.1
+ Revision: 132045
- 0.9.1
- Import tuxguitar

* Mon Sep 04 2006 David Walluck <walluck@mandriva.org> 0:0.8-2mdv2007.0
- add menu

* Sat Aug 26 2006 David Walluck <walluck@mandriva.org> 0:0.8-1mdv2007.0
- 0.8

* Tue Jul 18 2006 David Walluck <david@jpackage.org> 0:0.7-1mdv2007.0
- 0.7

* Mon Jun 05 2006 David Walluck <david@jpackage.org> 0:0.4.1-2mdv2007.0
- rebuild for libcgj.so.7
- fix BuildRequires

* Fri Feb 24 2006 David Walluck <david@jpackage.org> 0:0.4.1-1mdk
- release

